@@ -31,6 +31,7 @@
 #include <libgupnp/gupnp.h>
 
 #include "gupnp-didl-lite-contributor.h"
+#include "gupnp-didl-lite-contributor-private.h"
 #include "xml-util.h"
 
 G_DEFINE_TYPE (GUPnPDIDLLiteContributor,
@@ -276,8 +277,6 @@ gupnp_didl_lite_contributor_get_name (GUPnPDIDLLiteContributor *contributor)
  * @role: The role of the @contributor
  *
  * Set the role of the @contributor to @role.
- *
- * Return value: None.
  **/
 void
 gupnp_didl_lite_contributor_set_role (GUPnPDIDLLiteContributor *contributor,
@@ -299,8 +298,6 @@ gupnp_didl_lite_contributor_set_role (GUPnPDIDLLiteContributor *contributor,
  * @name: The name of the contributor
  *
  * Set the name of the @contributor to @name.
- *
- * Return value: None.
  **/
 void
 gupnp_didl_lite_contributor_set_name (GUPnPDIDLLiteContributor *contributor,
@@ -332,8 +329,6 @@ GUPnPDIDLLiteContributor *
 gupnp_didl_lite_contributor_new_from_xml (xmlNode     *xml_node,
                                           GUPnPXMLDoc *xml_doc)
 {
-        GUPnPDIDLLiteContributor *contributor;
-
         return g_object_new (GUPNP_TYPE_DIDL_LITE_CONTRIBUTOR,
                              "xml-node", xml_node,
                              "xml-doc", xml_doc,
