@@ -30,6 +30,7 @@
 #include <string.h>
 
 #include "gupnp-didl-lite-descriptor.h"
+#include "gupnp-didl-lite-descriptor-private.h"
 #include "xml-util.h"
 
 G_DEFINE_TYPE (GUPnPDIDLLiteDescriptor,
@@ -315,8 +316,6 @@ GUPnPDIDLLiteDescriptor *
 gupnp_didl_lite_descriptor_new_from_xml (xmlNode     *xml_node,
                                          GUPnPXMLDoc *xml_doc)
 {
-        GUPnPDIDLLiteDescriptor *descriptor;
-
         return g_object_new (GUPNP_TYPE_DIDL_LITE_DESCRIPTOR,
                              "xml-node", xml_node,
                              "xml-doc", xml_doc,
@@ -413,8 +412,6 @@ gupnp_didl_lite_descriptor_get_name_space (GUPnPDIDLLiteDescriptor *descriptor)
  * @content: The content as string
  *
  * Set the content of the @descriptor.
- *
- * Return value: None.
  **/
 void
 gupnp_didl_lite_descriptor_set_content (GUPnPDIDLLiteDescriptor *descriptor,
@@ -439,8 +436,6 @@ gupnp_didl_lite_descriptor_set_content (GUPnPDIDLLiteDescriptor *descriptor,
  * @id: The ID as string
  *
  * Set the ID of the @descriptor.
- *
- * Return value: None.
  **/
 void
 gupnp_didl_lite_descriptor_set_id (GUPnPDIDLLiteDescriptor *descriptor,
@@ -462,8 +457,6 @@ gupnp_didl_lite_descriptor_set_id (GUPnPDIDLLiteDescriptor *descriptor,
  * @type: The metadata type as string
  *
  * Set the metadata type of the @descriptor.
- *
- * Return value: None.
  **/
 void
 gupnp_didl_lite_descriptor_set_metadata_type
@@ -486,8 +479,6 @@ gupnp_didl_lite_descriptor_set_metadata_type
  * @name_space: The name space URI as string
  *
  * Set the name space associated with the @descriptor.
- *
- * Return value: None.
  **/
 void
 gupnp_didl_lite_descriptor_set_name_space (GUPnPDIDLLiteDescriptor *descriptor,
