@@ -72,6 +72,9 @@ typedef struct {
         void (* _gupnp_reserved4) (void);
 } GUPnPDIDLLiteDescriptorClass;
 
+GUPnPDIDLLiteDescriptor *
+gupnp_didl_lite_descriptor_new (void);
+
 xmlNode *
 gupnp_didl_lite_descriptor_get_xml_node (GUPnPDIDLLiteDescriptor *descriptor);
 
