@@ -73,7 +73,12 @@ verify_didl_attributes (xmlNode *node)
                 }
         }
 
-        return xml_util_verify_attribute_is_boolean (node, "restricted");
+        if (xml_util_get_attribute_content (node, "restricted") != NULL) {
+                return xml_util_verify_attribute_is_boolean (node,
+                                                             "restricted");
+        }
+
+        return TRUE;
 }
 
 static gboolean
@@ -228,7 +233,6 @@ gupnp_didl_lite_parser_parse_didl_recursive (GUPnPDIDLLiteParser *parser,
 {
         xmlDoc       *doc;
         xmlNode      *element;
-        xmlNs       **ns_list;
         xmlNs        *upnp_ns = NULL;
         xmlNs        *dc_ns   = NULL;
         xmlNs        *dlna_ns = NULL;
